@@ -78,6 +78,15 @@ from .idl import lazy_load_cached_idl_parser as lazy_load_cached_idl_parser
 from .idsjsonmarketlookup import IdsJsonMarketLookup as IdsJsonMarketLookup
 from .inventory import Inventory as Inventory
 from .inventory import InventoryAccountWatcher as InventoryAccountWatcher
+from .instructions import (
+    build_mango_cache_perp_markets_instructions as build_mango_cache_perp_markets_instructions,
+)
+from .instructions import (
+    build_mango_cache_prices_instructions as build_mango_cache_prices_instructions,
+)
+from .instructions import (
+    build_mango_cache_root_banks_instructions as build_mango_cache_root_banks_instructions,
+)
 from .instructions import (
     build_mango_create_account_instructions as build_mango_create_account_instructions,
 )
@@ -96,6 +105,12 @@ from .instructions import (
 from .instructions import (
     build_mango_set_referrer_memory_instructions as build_mango_set_referrer_memory_instructions,
 )
+from .instructions import (
+    build_mango_update_funding_instructions as build_mango_update_funding_instructions,
+)
+from .instructions import (
+    build_mango_update_root_bank_instructions as build_mango_update_root_bank_instructions,
+)
 from .instructions import (
     build_mango_unset_account_delegate_instructions as build_mango_unset_account_delegate_instructions,
 )
