@@ -93,9 +93,15 @@ class SpotMarket(LoadedMarket):
     @staticmethod
     def ensure(market: Market) -> "SpotMarket":
         if not SpotMarket.isa(market):
-            raise Exception(f"Market for {market.symbol} is not a Spot market")
+            raise Exception(
+                f"Market for {market.fully_qualified_symbol} is not a Spot market"
+            )
         return typing.cast(SpotMarket, market)
 
+    @property
+    def fully_qualified_symbol(self) -> str:
+        return f"spot:{self.symbol}"
+
     @property
     def bids_address(self) -> PublicKey:
         return self.underlying_serum_market.state.bids()
@@ -292,21 +298,38 @@ class SpotMarketInstructionBuilder(MarketInstructionBuilder):
         if order.match_limit != Order.DefaultMatchLimit:
             self._logger.warning("Ignoring match_limit - not supported on Spot markets")
 
-        create_open_orders: bool = False
         slot = self.group.slot_by_spot_market_address(self.spot_market.address)
         market_index = slot.index
         open_orders_address: typing.Optional[
             PublicKey
         ] = self.account.spot_open_orders_by_index[market_index]
 
+        instructions = CombinableInstructions.empty()
         if open_orders_address is None:
             # Spot OpenOrders accounts use a PDA as of v3.3
             open_orders_address = self.spot_market.derive_open_orders_address(
                 self.context, self.account
             )
-            create_open_orders = True
+            instructions += build_spot_create_openorders_instructions(
+                self.context,
+                self.wallet,
+                self.group,
+                self.account,
+                self.spot_market,
+                open_orders_address,
+            )
 
-        instructions = build_spot_place_order_instructions(
+            # This line is a little nasty. Now that we know we have an OpenOrders account at
+            # this address, update the IAccount so that future uses (like later in this
+            # method) have access to it in the right place.
+            #
+            # This might cause problems if this instruction is never sent or the transaction
+            # fails though.
+            self.account.update_spot_open_orders_for_market(
+                market_index, open_orders_address
+            )
+
+        instructions += build_spot_place_order_instructions(
             self.context,
             self.wallet,
             self.group,
@@ -319,13 +342,6 @@ class SpotMarketInstructionBuilder(MarketInstructionBuilder):
             order.quantity,
             order.client_id,
             self.fee_discount_token_address,
-            create_open_orders,
-        )
-
-        # This line is a little nasty. Now that we know we have an OpenOrders account at this address, update
-        # the IAccount so that future uses (like later in this method) have access to it in the right place.
-        self.account.update_spot_open_orders_for_market(
-            market_index, open_orders_address
         )
 
         return instructions
@@ -410,7 +426,7 @@ class SpotMarketInstructionBuilder(MarketInstructionBuilder):
         )
 
     def __str__(self) -> str:
-        return f"« SpotMarketInstructionBuilder [{self.spot_market.symbol}] »"
+        return f"« SpotMarketInstructionBuilder [{self.spot_market.fully_qualified_symbol}] »"
 
 
 # # 🥭 SpotMarketOperations class
@@ -459,7 +475,9 @@ class SpotMarketOperations(MarketOperations):
     def cancel_order(
         self, order: Order, ok_if_missing: bool = False
     ) -> typing.Sequence[str]:
-        self._logger.info(f"Cancelling {self.spot_market.symbol} order {order}.")
+        self._logger.info(
+            f"Cancelling {self.spot_market.fully_qualified_symbol} order {order}."
+        )
         signers: CombinableInstructions = CombinableInstructions.from_wallet(
             self.wallet
         )
@@ -486,7 +504,9 @@ class SpotMarketOperations(MarketOperations):
         order_with_client_id: Order = order.with_update(
             client_id=client_id
         ).with_update(owner=self.open_orders_address or SYSTEM_PROGRAM_ADDRESS)
-        self._logger.info(f"Placing {self.spot_market.symbol} order {order}.")
+        self._logger.info(
+            f"Placing {self.spot_market.fully_qualified_symbol} order {order}."
+        )
         place: CombinableInstructions = (
             self.market_instruction_builder.build_place_order_instructions(
                 order_with_client_id
@@ -577,7 +597,7 @@ class SpotMarketOperations(MarketOperations):
         )
 
     def __str__(self) -> str:
-        return f"« SpotMarketOperations [{self.spot_market.symbol}] »"
+        return f"« SpotMarketOperations [{self.spot_market.fully_qualified_symbol}] »"
 
 
 # # 🥭 SpotMarketStub class
@@ -606,6 +626,10 @@ class SpotMarketStub(Market):
         self.quote: Token = quote
         self.group_address: PublicKey = group_address
 
+    @property
+    def fully_qualified_symbol(self) -> str:
+        return f"spot:{self.symbol}"
+
     def load(self, context: Context, group: typing.Optional[Group]) -> SpotMarket:
         actual_group: Group = group or Group.load(context, self.group_address)
         underlying_serum_market: PySerumMarket = PySerumMarket.load(
